#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses
import oss
import events
import window


class mixerwin(window.window):

    def __init__(self, screen, h, w, y, x, channel, timer, device_channel, keybindings):
        self.channel = channel
        self.timer = timer
        self.mixer_device = device_channel[0]
        self.mixer_channel = eval("oss.%s" % device_channel[1])
        self.mixer = oss.open_mixer(self.mixer_device)
        self.keybindings = keybindings
        self.level = self.mixer.read_channel(self.mixer_channel)

        # for identification purposes, we only generate this once
        self.hidewindowevent = events.hidewindow(self)
        
        
        window.window.__init__(self,
                               screen, h, w, y, x, "Mixer", 0)

        self.hide()

        self.channel.subscribe(events.keypressed, self.keypressed)
        self.channel.subscribe(events.hidewindow, self.hidewindow)

    def changevolume(self, change):
        oldlevel = self.mixer.read_channel(self.mixer_channel)
        self.level= ( max(0, min(oldlevel[0]+change, 100)),
                      max(0, min(oldlevel[1]+change, 100)) )
        self.mixer.write_channel(self.mixer_channel, self.level)
        
    # event handler

    def keypressed(self, event):
        key = event.key
        if key in self.keybindings["volumeup"]:
            self.changevolume(+5)
        elif key in self.keybindings["volumedown"]:
            self.changevolume(-5)
        else:
            if self.hasfocus():
                self.hide()
            return

        self.update()
        self.timer.sendeventin(self.hidewindowevent, 5, replace=1)
        
        raise events.TerminateEventProcessing

    def update(self):
        self.top()
        window.window.update(self)
        self.win.addstr(1,2, "Volume: ", curses.A_BOLD)
        self.win.addstr("%3d  " % self.level[0])
        self.win.move(1, 14)

        barlen = self.w - 16
        percent = barlen*self.level[0]/100
        for i in range(barlen):
            self.win.addch(ord("#"),
                           i<percent and curses.A_BOLD or curses.A_NORMAL)


        
